gchecky.model.digital_content_t

Package gchecky :: Module model :: Class digital_content_t |
[hide private]
[frames] | no frames]

# Class digital_content_t

source code

    object --+
             |
     gxml.Node --+
                 |
                digital_content_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| description = `Html:PATH(description):OPT`
| email_delivery = `gxml.Boolean('email-delivery', required= False)`
| key = `String:PATH(key):OPT`
| url = `String:PATH(url):OPT`
| display_disposition = `String:PATH(display-disposition):OPT:VAL`...``
| _fields = ``{``'``description``'``:` Html:PATH(description):OPT`,` `'``display``...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### display_disposition Value:
      String:PATH(display-disposition):OPT:VALS("OPTIMISTIC","PESSIMISTIC")

  ### _fields list of meta-Fields of this class. Value:
      {'description': Html:PATH(description):OPT,
       'display_disposition': String:PATH(display-disposition):OPT:VALS("OPT
      IMISTIC","PESSIMISTIC"),
       'email_delivery': ??,
       'key': String:PATH(key):OPT,
       'url': String:PATH(url):OPT}